==> 0.0.2.tar.gz: example/lib/pages/login.dart <==
import 'dart:ui';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin/class/V2TIMSDKConfig.dart';
import 'package:flutter/material.dart';
import 'package:dio/dio.dart';
import 'package:toast/toast.dart';

var timBaseColor = Color(int.parse('006fff', radix: 16)).withAlpha(255);
var timLogo = AssetImage("images/logo.png");

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  Future<void> initState() {
    super.initState();
    test();
  }

  listener(data) {
    print("init sdk listener emit");
    if (data["type"] == "onSelfInfoUpdated") {
      print(data["data"]);
      return;
    }
    print(data);
  }

  groupListener(data) {
    print("groupListener emit");
    print(data);
  }

  advancedMsgListener(data) {}
  friendListener(data) {}
  conversationListener(data) {}
  signalingListener(data) {}
  test() async {
    await tencent_im_sdk_plugin.v2TIMManager
        .initSDK(1400425583, V2TIMSDKConfig.V2TIM_LOG_ERROR, listener);

    //简单监听
    tencent_im_sdk_plugin.v2TIMManager.addSimpleMsgListener(
      simpleMsgListener,
    );
    // tencent_im_sdk_plugin.v2TIMManager.addSimpleMsgListener(
    //   simpleMsgListener1,
    // );
    //群组监听
    tencent_im_sdk_plugin.v2TIMManager.setGroupListener(
      groupListener,
    );
    //高级消息监听
    tencent_im_sdk_plugin.v2TIMManager
        .getMessageManager()
        .addAdvancedMsgListener(
          advancedMsgListener,
        );
    //关系链监听
    tencent_im_sdk_plugin.v2TIMManager.getFriendshipManager().setFriendListener(
          friendListener,
        );
    //会话监听
    tencent_im_sdk_plugin.v2TIMManager
        .getConversationManager()
        .setConversationListener(
          conversationListener,
        );
    tencent_im_sdk_plugin.v2TIMManager
        .getSignalingManager()
        .addSignalingListener(
          signalingListener,
        );
    print("初始化完成了");
    await tencent_im_sdk_plugin.v2TIMManager.login(
      "xingchenhe",
      "eJwtzMsKgzAQheF3ybZFEs3gBbpoQQTJQrBot1LHOFiD2mCF0nevqMvzHfi-7K5yZ8aJRcx1ODtvm2o0lhraeCGjny2aFo-3XXfVMFDNIiE5ly5A4O0PLgNNuDoAuJzzXS31m4VhIKQvg6NCeo0XsVAP2Vnom9Ibi6SfSzNmWZhjXKVJKrT6QF75t9PremG-P3dgMxU_",
    );
    // Map res =  await tencent_im_sdk_plugin.v2TIMManager
    //     .setSelfInfo(nickName: 'hahaha11122233');
    // await tencent_im_sdk_plugin.v2TIMManager.addSimpleMsgListener();
    // await tencent_im_sdk_plugin.v2TIMManager.login(
    //   "clavieliu",
    //   "eJwtzE0PwUAUheH-MlvSXjXDtImFoEJIhG5INzW96lIyGaORiv*uX8vznOT9smhzcAo0LGCeA6zfbErxaelCDas8KQhzenfnK70nWlPKggEH4J4Qctg**NFksHIhhAcArVp61DaqgPtj3*8qlNVto5dHpaSMrM1i9zRFdd3ZbXiGeU8uSpqVq9gNlcH1bZ9N2O8Pq5w0Dg__",
    // );
    // print("登录完成了");

    // await tencent_im_sdk_plugin.v2TIMManager.getLoginUser();
    // print("获取用户信息完成了");
    // await tencent_im_sdk_plugin.v2TIMManager.getLoginStatus();
    // Map data = await tencent_im_sdk_plugin.v2TIMManager.sendC2CTextMessage(
    //   "hello",
    //   "clavieliu",
    // );
    // print(22222);
    // print(data);
    // tencent_im_sdk_plugin.v2TIMManager
    //     .getConversationManager()
    //     .setConversationListener();

    // List<String> userIdLists = new List();
    // userIdLists.add("xingchenhe");
    // print(userIdLists);
    // await tencent_im_sdk_plugin.v2TIMManager.getUsersInfo(userIdLists);
    // Map data = await tencent_im_sdk_plugin.v2TIMManager
    //     .sendC2CCustomMessage("test", "clavieliu");
    // print(data);
    Map data = await tencent_im_sdk_plugin.v2TIMManager.sendGroupCustomMessage(
      "哈哈哈哈哈哈哈",
      "@TGS#1UJ2UNWGR",
      1,
    );
    print(data);
    // tencent_im_sdk_plugin.v2TIMManager.createGroup(
    //   "AVChatRoom",
    //   "testgroupid",
    //   "flutter创建",
    // );
    // tencent_im_sdk_plugin.v2TIMManager.createGroup(
    //   "Work",
    //   "flutter创建无id",
    //   null,
    // );
    // tencent_im_sdk_plugin.v2TIMManager.quitGroup("testgroupid");
    // tencent_im_sdk_plugin.v2TIMManager.dismissGroup("@TGS#aASIUNWGP");
    // tencent_im_sdk_plugin.v2TIMManager
    //     .getConversationManager()
    //     .getConversationList(0, 1);
  }

  simpleMsgListener(data) {
    //这里区分消息
    print("simpleMsgListener emit");

    print(data);
  }

  simpleMsgListener1(data) {
    print("simpleMsgListener1 emit");

    print(data);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: new AppLayout(),
      ),
    );
  }
}

class AppLayout extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new Flex(
      direction: Axis.vertical,
      children: <Widget>[
        Expanded(
          child: new AppLogo(),
          flex: 0,
        ),
        Expanded(
          child: new LoginForm(),
          flex: 1,
        ),
      ],
    );
  }
}

class AppLogo extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 192.0,
      color: timBaseColor,
      alignment: Alignment.topLeft,
      padding: EdgeInsets.only(
        top: 108.0,
      ),
      child: Row(
        children: <Widget>[
          Container(
            height: 90,
            width: 90,
            child: Image(
              image: timLogo,
              width: 90.0,
              height: 90.0,
            ),
          ),
          Container(
            height: 90.0,
            padding: EdgeInsets.only(
              top: 10,
            ),
            child: Column(
              children: <Widget>[
                Text(
                  '登录·即时通信',
                  style: TextStyle(
                    color: Color.fromARGB(255, 255, 255, 255),
                    fontSize: 28,
                  ),
                ),
                Text(
                  '体验群组聊天，音视频对话等M功能',
                  style: TextStyle(
                    color: Color.fromARGB(255, 255, 255, 255),
                    fontSize: 12,
                  ),
                ),
              ],
              crossAxisAlignment: CrossAxisAlignment.start,
            ),
          )
        ],
      ),
    );
  }
}

class LoginForm extends StatefulWidget {
  _LoginFormState createState() => _LoginFormState();
}

class _LoginFormState extends State<LoginForm> {
  void initState() {}
  String tel = '';
  String pwd = '';
  void getHttp() async {
    try {
      Response response = await Dio().get(
        "https://service-qr8jjnpm-1256635546.gz.apigw.tencentcs.com/release/getUserSig?userId=xingchenhe",
      );
      print(response);
    } catch (e) {
      print(e);
    }
  }

  void getLoginCode(context) async {
    if (tel.length == 0) {
      Toast.show(
        "请输入正确的手机号码",
        context,
        duration: Toast.LENGTH_SHORT,
        gravity: Toast.TOP,
      );
    } else {
      Dio dio = new Dio();
      Response response = await dio.get(
          "https://service-c2zjvuxa-1252463788.gz.apigw.tencentcs.com/release/flutterSms",
          queryParameters: {
            "method": "getSms",
            "phone": tel,
          });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
        top: 62,
        left: 12,
        right: 12,
      ),
      child: Form(
        child: Column(
          children: <Widget>[
            TextField(
              autofocus: false,
              decoration: InputDecoration(
                labelText: "手机号",
                hintText: "请输入手机号码",
                icon: Icon(Icons.phone_android),
              ),
              keyboardType: TextInputType.number,
              onChanged: (v) {
                setState(() {
                  tel = v;
                });
              },
            ),
            Flex(
              direction: Axis.horizontal,
              children: <Widget>[
                Expanded(
                  child: TextField(
                    decoration: InputDecoration(
                      labelText: "验证码",
                      hintText: "请输入验证码",
                      icon: Icon(Icons.lock),
                    ),
                    keyboardType: TextInputType.number,
                    //校验密码
                    onChanged: (v) {
                      setState(() {
                        pwd = v;
                      });
                    },
                  ),
                  flex: 2,
                ),
                Expanded(
                  child: RaisedButton(
                    child: Text("获取验证码"),
                    color: timBaseColor,
                    textColor: Colors.white,
                    onPressed: () {
                      //获取验证码
                      getLoginCode(context);
                    },
                  ),
                  flex: 1,
                )
              ],
            ),
            Padding(
              padding: const EdgeInsets.only(top: 28.0),
              child: Row(
                children: <Widget>[
                  Expanded(
                    child: RaisedButton(
                      padding: EdgeInsets.all(15.0),
                      child: Text("登录"),
                      color: timBaseColor,
                      textColor: Colors.white,
                      onPressed: () async {
                        //在这里不能通过此方式获取FormState，context不对
                        //print(Form.of(context));

                        // 通过_formKey.currentState 获取FormState后，
                        // 调用validate()方法校验用户名密码是否合法，校验
                        // 通过后再提交数据。
                        // if((_formKey.currentState as FormState).validate()){
                        //   //验证通过提交数据
                        // }
                        // this.getHttp();
                        // var callback = new Logincallback();
                        String userID = 'xingchenhe';
                        String userSig =
                            'eJwtzEsLgkAUhuH-MttCjtpxVHBTmy52ATPcSk56iGyaGUOK-nsyuvyeD94vO6eZ8xaKxcxzgM3tpkq0hm5kuae2vjaibcT06upeSkkVi90FgI8cw2h8RC9JicER0QOAUQ09rEUBcM7RnSpUD-Goe5W*2pKi3pjV8qnDWRd4aX755GvUWXoojk3R7TbytE-Y7w*SojQO';
                        // dynamic res = await tencent_im_sdk_plugin.login(
                        //   userID: userID,
                        //   userSig: userSig,
                        // );
                        print(223);
                        // print(res["code"]);
                        // if (res["code"] == 0) {
                        //   Navigator.push(
                        //     context,
                        //     new MaterialPageRoute(
                        //       builder: (context) => new HomePage(),
                        //     ),
                        //   );
                        // }
                      },
                    ),
                  ),
                ],
              ),
            )
          ],
        ),
      ),
    );
  }
}

==> 0.0.5.tar.gz: example/lib/pages/login.dart <==
import 'dart:ui';
import 'home.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin/class/V2TIMSDKConfig.dart';
import 'package:flutter/material.dart';
import 'package:dio/dio.dart';
import 'package:toast/toast.dart';

var timBaseColor = Color(int.parse('006fff', radix: 16)).withAlpha(255);
var timLogo = AssetImage("images/logo.png");

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  Future<void> initState() {
    super.initState();
    test();
  }

  listener(data) {
    print("init sdk listener emit");
    if (data["type"] == "onSelfInfoUpdated") {
      print(data["data"]);
      return;
    }
    print(data);
  }

  groupListener(data) {
    print("groupListener emit");
    print(data);
  }

  advancedMsgListener(data) {
    print("advancedMsgListener emit");
    print(data);
  }

  friendListener(data) {
    print("friendListener emit");
    print(data);
  }

  conversationListener(data) {
    print("conversationListener emit");
    print(data);
  }

  signalingListener(data) {
    print("signalingListener emit");
    print(data);
  }

  test() async {
    await tencent_im_sdk_plugin.v2TIMManager
        .initSDK(1400425583, V2TIMSDKConfig.V2TIM_LOG_ERROR, listener);

    //简单监听
    tencent_im_sdk_plugin.v2TIMManager.addSimpleMsgListener(
      simpleMsgListener,
    );

    //群组监听
    tencent_im_sdk_plugin.v2TIMManager.setGroupListener(
      groupListener,
    );
    //高级消息监听
    tencent_im_sdk_plugin.v2TIMManager
        .getMessageManager()
        .addAdvancedMsgListener(
          advancedMsgListener,
        );
    //关系链监听
    tencent_im_sdk_plugin.v2TIMManager.getFriendshipManager().setFriendListener(
          friendListener,
        );
    //会话监听
    tencent_im_sdk_plugin.v2TIMManager
        .getConversationManager()
        .setConversationListener(
          conversationListener,
        );
    tencent_im_sdk_plugin.v2TIMManager
        .getSignalingManager()
        .addSignalingListener(
          signalingListener,
        );
    print("初始化完成了");

    // Map res =  await tencent_im_sdk_plugin.v2TIMManager
    //     .setSelfInfo(nickName: 'hahaha11122233');
    // await tencent_im_sdk_plugin.v2TIMManager.addSimpleMsgListener();
    // await tencent_im_sdk_plugin.v2TIMManager.login(
    //   "clavieliu",
    //   "eJwtzE0PwUAUheH-MlvSXjXDtImFoEJIhG5INzW96lIyGaORiv*uX8vznOT9smhzcAo0LGCeA6zfbErxaelCDas8KQhzenfnK70nWlPKggEH4J4Qctg**NFksHIhhAcArVp61DaqgPtj3*8qlNVto5dHpaSMrM1i9zRFdd3ZbXiGeU8uSpqVq9gNlcH1bZ9N2O8Pq5w0Dg__",
    // );
    // print("登录完成了");

    // await tencent_im_sdk_plugin.v2TIMManager.getLoginUser();
    // print("获取用户信息完成了");
    // await tencent_im_sdk_plugin.v2TIMManager.getLoginStatus();
    // Map data = await tencent_im_sdk_plugin.v2TIMManager.sendC2CTextMessage(
    //   "hello",
    //   "clavieliu",
    // );
    // print(22222);
    // print(data);
    // tencent_im_sdk_plugin.v2TIMManager
    //     .getConversationManager()
    //     .setConversationListener();

    // List<String> userIdLists = new List();
    // userIdLists.add("xingchenhe");
    // print(userIdLists);
    // await tencent_im_sdk_plugin.v2TIMManager.getUsersInfo(userIdLists);
    // Map data = await tencent_im_sdk_plugin.v2TIMManager
    //     .sendC2CCustomMessage("test", "clavieliu");
    // print(data);
    // Map data = await tencent_im_sdk_plugin.v2TIMManager.sendGroupCustomMessage(
    //   "哈哈哈哈哈哈哈",
    //   "@TGS#1UJ2UNWGR",
    //   1,
    // );
    // print(data);
    // tencent_im_sdk_plugin.v2TIMManager.createGroup(
    //   "AVChatRoom",
    //   "testgroupid",
    //   "flutter创建",
    // );
    // tencent_im_sdk_plugin.v2TIMManager.createGroup(
    //   "Work",
    //   "flutter创建无id",
    //   null,
    // );
    // tencent_im_sdk_plugin.v2TIMManager.quitGroup("testgroupid");
    // tencent_im_sdk_plugin.v2TIMManager.dismissGroup("@TGS#aASIUNWGP");
    // tencent_im_sdk_plugin.v2TIMManager
    //     .getConversationManager()
    //     .getConversationList(0, 1);
  }

  simpleMsgListener(data) {
    //这里区分消息
    print("simpleMsgListener emit");

    print(data);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: new AppLayout(),
      ),
    );
  }
}

class AppLayout extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new Flex(
      direction: Axis.vertical,
      children: <Widget>[
        Expanded(
          child: new AppLogo(),
          flex: 0,
        ),
        Expanded(
          child: new LoginForm(),
          flex: 1,
        ),
      ],
    );
  }
}

class AppLogo extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 192.0,
      color: timBaseColor,
      alignment: Alignment.topLeft,
      padding: EdgeInsets.only(
        top: 108.0,
      ),
      child: Row(
        children: <Widget>[
          Container(
            height: 90,
            width: 90,
            child: Image(
              image: timLogo,
              width: 90.0,
              height: 90.0,
            ),
          ),
          Container(
            height: 90.0,
            padding: EdgeInsets.only(
              top: 10,
            ),
            child: Column(
              children: <Widget>[
                Text(
                  '登录·即时通信',
                  style: TextStyle(
                    color: Color.fromARGB(255, 255, 255, 255),
                    fontSize: 28,
                  ),
                ),
                Text(
                  '体验群组聊天，音视频对话等M功能',
                  style: TextStyle(
                    color: Color.fromARGB(255, 255, 255, 255),
                    fontSize: 12,
                  ),
                ),
              ],
              crossAxisAlignment: CrossAxisAlignment.start,
            ),
          )
        ],
      ),
    );
  }
}

class LoginForm extends StatefulWidget {
  _LoginFormState createState() => _LoginFormState();
}

class _LoginFormState extends State<LoginForm> {
  void initState() {}
  String tel = '';
  String pwd = '';
  void getHttp() async {
    try {
      Response response = await Dio().get(
        "https://service-qr8jjnpm-1256635546.gz.apigw.tencentcs.com/release/getUserSig?userId=xingchenhe",
      );
      print(response);
    } catch (e) {
      print(e);
    }
  }

  void getLoginCode(context) async {
    if (tel.length == 0) {
      Toast.show(
        "请输入正确的手机号码",
        context,
        duration: Toast.LENGTH_SHORT,
        gravity: Toast.TOP,
      );
    } else {
      Dio dio = new Dio();
      Response response = await dio.get(
          "https://service-c2zjvuxa-1252463788.gz.apigw.tencentcs.com/release/flutterSms",
          queryParameters: {
            "method": "getSms",
            "phone": tel,
          });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
        top: 62,
        left: 12,
        right: 12,
      ),
      child: Form(
        child: Column(
          children: <Widget>[
            TextField(
              autofocus: false,
              decoration: InputDecoration(
                labelText: "手机号",
                hintText: "请输入手机号码",
                icon: Icon(Icons.phone_android),
              ),
              keyboardType: TextInputType.number,
              onChanged: (v) {
                setState(() {
                  tel = v;
                });
              },
            ),
            Flex(
              direction: Axis.horizontal,
              children: <Widget>[
                Expanded(
                  child: TextField(
                    decoration: InputDecoration(
                      labelText: "验证码",
                      hintText: "请输入验证码",
                      icon: Icon(Icons.lock),
                    ),
                    keyboardType: TextInputType.number,
                    //校验密码
                    onChanged: (v) {
                      setState(() {
                        pwd = v;
                      });
                    },
                  ),
                  flex: 2,
                ),
                Expanded(
                  child: RaisedButton(
                    child: Text("获取验证码"),
                    color: timBaseColor,
                    textColor: Colors.white,
                    onPressed: () {
                      //获取验证码
                      getLoginCode(context);
                    },
                  ),
                  flex: 1,
                )
              ],
            ),
            Padding(
              padding: const EdgeInsets.only(top: 28.0),
              child: Row(
                children: <Widget>[
                  Expanded(
                    child: RaisedButton(
                      padding: EdgeInsets.all(15.0),
                      child: Text("登录"),
                      color: timBaseColor,
                      textColor: Colors.white,
                      onPressed: () async {
                        await tencent_im_sdk_plugin.v2TIMManager.login(
                          "xingchenhe",
                          "eJwtzMsKgzAQheF3ybZFEs3gBbpoQQTJQrBot1LHOFiD2mCF0nevqMvzHfi-7K5yZ8aJRcx1ODtvm2o0lhraeCGjny2aFo-3XXfVMFDNIiE5ly5A4O0PLgNNuDoAuJzzXS31m4VhIKQvg6NCeo0XsVAP2Vnom9Ibi6SfSzNmWZhjXKVJKrT6QF75t9PremG-P3dgMxU_",
                        );
                        print('login success');
                        Navigator.push(
                          context,
                          new MaterialPageRoute(
                            builder: (context) => HomePage(),
                          ),
                        );
                      },
                    ),
                  ),
                ],
              ),
            )
          ],
        ),
      ),
    );
  }
}
